@@ -34,7 +34,6 @@ class ResultsIngestor:
             )
 
         self.consumer_timeout = consumer_timeout
-        self.max_queue_size = 1000  # Maximum queue size for health monitoring
 
         # Result queues for each deployment (now using PriorityQueue)
         self.results_queues: Dict[str, PriorityQueue] = {}
@@ -76,36 +75,6 @@ class ResultsIngestor:
             self.results_queues[deployment_id] = PriorityQueue()
             self.stats["queue_sizes"][deployment_id] = 0
     
-    def _get_priority_counter(self, deployment_id: str, stream_key: str, input_order: int) -> Tuple[int, int, int]:
-        """
-        Get priority tuple for queue ordering with reset detection.
-        
-        Returns:
-            Tuple[session_id, temporal_counter, input_order]: Priority tuple for queue ordering
-        """
-        key = (deployment_id, stream_key)
-        
-        # Initialize counters if needed
-        if key not in self._counters:
-            self._counters[key] = itertools.count()
-            self._last_input_order[key] = -1
-            self._session_counters[key] = 0
-        
-        # Get current temporal counter (always increments)
-        temporal_counter = next(self._counters[key])
-        
-        # Detect input_order reset (significant decrease suggests reset)
-        last_input_order = self._last_input_order[key]
-        if last_input_order != -1 and input_order < last_input_order - 5:  # Allow some tolerance for out-of-order
-            # Input order reset detected - increment session counter
-            self._session_counters[key] += 1
-            logging.info(f"Input order reset detected for {deployment_id}:{stream_key} - {last_input_order} -> {input_order}, session: {self._session_counters[key]}")
-        
-        # Update last seen input_order
-        self._last_input_order[key] = input_order
-        
-        # Return (session_id, temporal_counter, input_order) for proper ordering
-        return (self._session_counters[key], temporal_counter, input_order)
 
     def start_streaming(self) -> bool:
         """
@@ -189,6 +158,21 @@ class ResultsIngestor:
 
         logging.info("Results streaming stopped")
 
+    def _get_priority_counter(self, deployment_id: str, stream_key: str, stream_group_key: str) -> int:
+        """
+        Get priority tuple for queue ordering with reset detection.
+        
+        Returns:
+            Tuple[session_id, temporal_counter, input_order]: Priority tuple for queue ordering
+        """
+        key = (deployment_id, stream_key, stream_group_key)
+        
+        # Initialize counters if needed
+        if key not in self._counters:
+            self._counters[key] = itertools.count()
+        
+        return next(self._counters[key])
+
     def _stream_results_to_queue(
         self, deployment_id: str, results_queue: PriorityQueue
     ):
@@ -213,39 +197,31 @@ class ResultsIngestor:
                     result_value = result.get("value", {})
                     input_streams = result_value.get("input_streams", [])
                     input_stream = input_streams[0]["input_stream"] if input_streams else {}
-                    input_order = input_stream.get("input_order")
+                    # input_order = input_stream.get("input_order")
                     camera_info = input_stream.get("camera_info")
                     stream_key = camera_info.get("camera_name")
-                    stream_group_key = camera_info.get("camera_group")
+                    stream_group_key = camera_info.get("camera_group") or "default_group"
 
-                    if not stream_key or input_order is None:
+                    if not stream_key:
                         logging.warning(
-                            f"Missing stream_key or input_order for deployment {deployment_id}, skipping result. "
-                            f"Stream key: {stream_key}, Input order: {input_order}, Stream group: {stream_group_key}"
+                            f"Missing stream_key for deployment {deployment_id}, skipping result. "
+                            f"Stream key: {stream_key}, Stream group: {stream_group_key}"
                         )
                         continue
                     
-
-                    # Get priority tuple with reset detection
-                    priority_tuple = self._get_priority_counter(deployment_id, stream_key, input_order)
-                    session_id, temporal_counter, _ = priority_tuple
-
+                    order = self._get_priority_counter(deployment_id, stream_key, stream_group_key)
                     # Create enhanced result object with the structured response
                     enhanced_result = {
                         "deployment_id": deployment_id,
                         "stream_key": stream_key,
                         "stream_group_key": stream_group_key,
-                        "input_order": input_order,
-                        "session_id": session_id,  # Add session ID for proper synchronization
-                        "temporal_counter": temporal_counter,  # Add temporal counter for debugging
+                        "input_order": order,
                         "timestamp": time.time(),
                         "result": result_value, # TODO: check if should send this or just agg_summary
                     }
 
-                    # Add to priority queue (non-blocking) with proper ordering
-                    # Priority: (session_id, temporal_counter, input_order) ensures correct ordering even with resets
                     try:
-                        results_queue.put((priority_tuple, enhanced_result), block=False)
+                        results_queue.put((order, enhanced_result), block=False)
 
                         with self._lock:
                             self.stats["results_consumed"] += 1
@@ -367,10 +343,10 @@ class ResultsIngestor:
                 total_queue_size += queue_size
 
                 # Mark as degraded if queue is getting full
-                if queue_size > self.max_queue_size * 0.8:
+                if queue_size > 1000:
                     health["status"] = "degraded"
-                    health["reason"] = f"Queue for {deployment_id} nearly full ({queue_size}/{self.max_queue_size})"
-                    logging.warning(f"Ingestor degraded: {deployment_id} queue has {queue_size} items (threshold: {self.max_queue_size * 0.8})")
+                    health["reason"] = f"Queue for {deployment_id} nearly full ({queue_size})"
+                    logging.warning(f"Ingestor degraded: {deployment_id} queue has {queue_size} items")
 
         # Check for recent errors (within last 60 seconds)
         if (
@@ -419,4 +395,10 @@ class ResultsIngestor:
                 pass
 
         self.results_queues.clear()
+        
+        # Clear tracking data
+        self._counters.clear()
+        self._last_input_order.clear()
+        self._session_counters.clear()
+        
         logging.info("Results streamer cleanup completed")
