@@ -9,6 +9,7 @@ from matrice.deploy.client.streaming_gateway.streaming_gateway_utils import (
     OutputConfig,
     InputType,
     ModelInputType,
+    _RealTimeJsonEventPicker,
 )
 from matrice.deploy.client.streaming_gateway.streaming_results_handler import (
     StreamingResultsHandler,
@@ -60,6 +61,7 @@ class StreamingGateway:
         service_id: str = None,
         inputs_config: List[InputConfig] = None,
         output_config: OutputConfig = None,
+        json_event_picker: _RealTimeJsonEventPicker = _RealTimeJsonEventPicker(),
         create_deployment_config: Dict = None,
         auth_key: str = None,
         consumer_group_id: str = None,
@@ -111,6 +113,7 @@ class StreamingGateway:
                 raise ValueError(f"Input config {i} must be an InputConfig instance")
 
         self.output_config = output_config
+        self.json_event_picker = json_event_picker
         self.consumer_group_id = consumer_group_id
         self.result_callback = result_callback
         self.kafka_producer = None
@@ -152,6 +155,7 @@ class StreamingGateway:
             self.results_handler = StreamingResultsHandler(
                 client_stream_utils=self.client_stream_utils,
                 output_config=self.output_config,
+                json_event_picker=self.json_event_picker,
                 service_id=self.service_id,
                 strip_input_from_result=self.strip_input_from_result,
                 result_callback=self.result_callback,
