@@ -114,6 +114,9 @@ from .usecases.car_part_segmentation import CarPartSegmentationUseCase, CarPartS
 from .usecases.windmill_maintenance import WindmillMaintenanceUseCase, WindmillMaintenanceConfig
 from .usecases.flower_segmentation import FlowerUseCase, FlowerConfig
 from .usecases.leaf import LeafConfig, LeafUseCase
+from .usecases.litter_monitoring import LitterDetectionUseCase,LitterDetectionConfig
+from .usecases.human_activity import HumanActivityUseCase, HumanActivityConfig
+from .usecases.gas_leak_detection import GasLeakDetectionConfig, GasLeakDetectionUseCase
 
 #Put all IMAGE based usecases here
 from .usecases.blood_cancer_detection_img import BloodCancerDetectionConfig, BloodCancerDetectionUseCase
@@ -173,6 +176,7 @@ from .usecases import (
     CarPartSegmentationUseCase,
     FlowerUseCase,
     SmokerDetectionUseCase,
+    LitterDetectionUseCase,
 
     #Put all IMAGE based usecases here
     BloodCancerDetectionUseCase,
@@ -239,6 +243,10 @@ _leaf_disease = LeafDiseaseDetectionUseCase()
 _flower_segmentation = FlowerUseCase()
 _leaf_det = LeafUseCase()
 _smoker_detection = SmokerDetectionUseCase()
+_litter_detection = LitterDetectionUseCase()
+_human_activity = HumanActivityUseCase()
+_gas_leak_detection = GasLeakDetectionUseCase()
+
 
 #Put all IMAGE based usecases here
 _blood_cancer_detection = BloodCancerDetectionUseCase()
@@ -246,7 +254,7 @@ _skin_cancer_classification = SkinCancerClassificationUseCase()
 _plaque_segmentation = PlaqueSegmentationUseCase()
 _histopathological_cancer_detection = HistopathologicalCancerDetectionUseCase()
 
-
+registry.register_use_case(_litter_detection.category, _litter_detection.name, LitterDetectionUseCase)
 registry.register_use_case(_people_counting.category, _people_counting.name, PeopleCountingUseCase)
 registry.register_use_case(_customer_service.category, _customer_service.name, CustomerServiceUseCase)
 registry.register_use_case(_advanced_customer_service.category, _advanced_customer_service.name, AdvancedCustomerServiceUseCase)
@@ -305,6 +313,8 @@ registry.register_use_case(_flower_segmentation.category, _flower_segmentation.n
 registry.register_use_case(_parking_det.category, _parking_det.name, ParkingUseCase)
 registry.register_use_case(_leaf_det.category, _leaf_det.name, LeafUseCase)
 registry.register_use_case(_smoker_detection.category, _smoker_detection.name, SmokerDetectionUseCase)
+registry.register_use_case(_human_activity.category, _human_activity.name, HumanActivityUseCase)
+registry.register_use_case(_gas_leak_detection.category, _gas_leak_detection.name, GasLeakDetectionUseCase)
 
 #Put all IMAGE based usecases here
 registry.register_use_case(_blood_cancer_detection.category, _blood_cancer_detection.name, BloodCancerDetectionUseCase)
@@ -493,6 +503,9 @@ __all__ = [
     'WindmillMaintenanceConfig',
     'FlowerConfig',
     'SmokerDetectionConfig',
+    'LitterDetectionConfig',
+    'GasLeakDetectionConfig',
+    'HumanActivityConfig',
 
     #Put all IMAGE based usecase CONFIGS here
     'BloodCancerDetectionConfig',
@@ -552,6 +565,9 @@ __all__ = [
     'WindmillMaintenanceUseCase',
     'FlowerUseCase',
     'SmokerDetectionUseCase',
+    'LitterDetectionUseCase',
+    'HumanActivityUseCase',
+    'GasLeakDetectionUseCase',
 
     #Put all IMAGE based usecases here
     'BloodCancerDetectionUseCase',
