@@ -43,6 +43,11 @@ APP_NAME_TO_USECASE = {
     "face_recognition": "face_recognition",
     "drowsy_driver_detection": "drowsy_driver_detection",
     "waterbody_segmentation": "waterbody_segmentation",
+    "litter_detection" : "litter_detection",
+    "leak_detection": "leak_detection",
+    "fire_smoke_detection": "fire_smoke_detection",
+    "human_activity": "human_activity",
+    "gas_leak_detection": "gas_leak_detection",
 }
 
 APP_NAME_TO_CATEGORY = {
@@ -90,6 +95,11 @@ APP_NAME_TO_CATEGORY = {
     "face_recognition": "security",
     "drowsy_driver_detection": "automobile",
     "waterbody_segmentation": "agriculture",
+    "litter_detection" : "litter_detection",
+    "leak_detection": "oil_gas",
+    "fire_smoke_detection": "hazard",
+    "human_activity": "general",
+    "gas_leak_detection": "oil_gas",
 }
 
 def get_usecase_from_app_name(app_name: str) -> str:
