@@ -454,6 +454,10 @@ class ConfigManager:
             'face_recognition': None,
             'drowsy_driver_detection': None,
             'waterbody_segmentation': None,
+            'litter_detection':None,
+            'leak_detection': None,
+            'human_activity': None,
+            'gas_leak_detection': None,
 
             #Put all image based usecases here::
             'blood_cancer_detection_img': None,
@@ -849,6 +853,38 @@ class ConfigManager:
             return WaterBodyConfig
         except ImportError:
             return None
+        
+    def litter_detection_config_class(self):
+        """Get Litter monitoring class to avoid circular imports."""
+        try:
+            from ..usecases.litter_monitoring import LitterDetectionConfig
+            return LitterDetectionConfig
+        except ImportError:
+            return None
+        
+    def leak_detection_config_class(self):
+        """Get Leak detection class to avoid circular imports."""
+        try:
+            from ..usecases.leak_detection import LeakDetectionConfig
+            return LeakDetectionConfig
+        except ImportError:
+            return None
+    
+    def human_activity_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.human_activity import HumanActivityConfig
+            return HumanActivityConfig
+        except ImportError:
+            return None
+    
+    def gas_leak_detection_config_class(self):
+        """Register a configuration class for a use case."""
+        try:
+            from ..usecases.gas_leak_detection import GasLeakDetectionConfig
+            return GasLeakDetectionConfig
+        except ImportError:
+            return None
     
     #put all image based usecases here::
     def blood_cancer_detection_config_class(self):
@@ -1786,6 +1822,69 @@ class ConfigManager:
                 **kwargs
             )
 
+        elif usecase == "litter_detection":
+            # Import here to avoid circular import
+            from ..usecases.litter_monitoring import LitterDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = LitterDetectionConfig(
+                category=category or "litter_detection",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+        
+        elif usecase == "leak_detection":
+            # Import here to avoid circular import
+            from ..usecases.leak_detection import LeakDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = LeakDetectionConfig(
+                category=category or "oil_gas",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
+        
+        elif usecase == "human_activity":
+            # Import here to avoid circular import
+            from ..usecases.human_activity import HumanActivityConfig
+
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = HumanActivityConfig(
+                category=category or "general",
+                usecase=usecase,
+                zone_config=zone_config,
+                alert_config=alert_config,
+                **kwargs
+            )
+            
+        elif usecase == "gas_leak_detection":
+            # Import here to avoid circular import
+            from ..usecases.gas_leak_detection import GasLeakDetectionConfig
+
+            # Handle nested configurations
+            alert_config = kwargs.pop("alert_config", None)
+            if alert_config and isinstance(alert_config, dict):
+                alert_config = AlertConfig(**alert_config)
+
+            config = GasLeakDetectionConfig(
+                category=category or "oil_gas",
+                usecase=usecase,
+                alert_config=alert_config,
+                **kwargs
+            )
         
         #Add IMAGE based usecases here::
         elif usecase == "blood_cancer_detection_img":
@@ -2230,6 +2329,28 @@ class ConfigManager:
             from ..usecases.waterbody_segmentation import WaterBodyConfig
             default_config = WaterBodyConfig()
             return default_config.to_dict()
+        
+        elif usecase == "litter_detection":
+            # Import here to avoid circular import
+            from ..usecases.litter_monitoring import LitterDetectionConfig
+            default_config = LitterDetectionConfig()
+            return default_config.to_dict()
+        
+        elif usecase == "leak_detection":
+            # Import here to avoid circular import
+            from ..usecases.leak_detection import LeakDetectionConfig
+            default_config = LeakDetectionConfig()
+            return default_config.to_dict()
+        elif usecase == "human_activity":
+            # Import here to avoid circular import
+            from ..usecases.human_activity import HumanActivityConfig
+            default_config = HumanActivityConfig()
+            return default_config.to_dict()
+        elif usecase == "gas_leak_detection":
+            # Import here to avoid circular import
+            from ..usecases.gas_leak_detection import GasLeakDetectionConfig
+            default_config = GasLeakDetectionConfig()
+            return default_config.to_dict()
 
         #Add all image based usecases here
         elif usecase == "blood_cancer_detection_img":
