@@ -59,7 +59,10 @@ from .usecases import (
     AntiSpoofingDetectionUseCase,
     ShelfInventoryUseCase,
     LaneDetectionUseCase,
-
+    LitterDetectionUseCase,
+    LeakDetectionUseCase,
+    HumanActivityUseCase,
+    GasLeakDetectionUseCase,
 
 
     AgeDetectionUseCase,
@@ -219,6 +222,10 @@ class PostProcessor:
         registry.register_use_case("security", "face_recognition", FaceRecognitionUseCase)
         registry.register_use_case("automobile", "drowsy_driver_detection", DrowsyDriverUseCase)
         registry.register_use_case("agriculture", "waterbody_segmentation", WaterBodyUseCase)
+        registry.register_use_case("litter_detection", "litter_detection", LitterDetectionUseCase)
+        registry.register_use_case("oil_gas", "leak_detection", LeakDetectionUseCase)
+        registry.register_use_case("general", "human_activity", HumanActivityUseCase)
+        registry.register_use_case("oil_gas", "gas_leak_detection", GasLeakDetectionUseCase)
 
         #Put all IMAGE based usecases here
         registry.register_use_case("healthcare", "bloodcancer_img_detection", BloodCancerDetectionUseCase)
@@ -389,7 +396,14 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, WaterBodyUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
-
+            elif isinstance(use_case, LitterDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, LeakDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, HumanActivityUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, GasLeakDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
             
             #Put all IMAGE based usecases here
             elif isinstance(use_case, BloodCancerDetectionUseCase):
